@@ -22,8 +22,9 @@ from calculate.lib.datavars import (TableVariable, Variable, ReadonlyVariable,
                                     VariableError, ReadonlyTableVariable,
                                     FieldValue, HumanReadable)
 from calculate.lib.utils.files import listDirectory, process, PIPE, pathJoin
-from calculate.lib.utils.portage import isPkgInstalled
+from calculate.lib.utils.portage import isPkgInstalled, RepositoryPath
 from calculate.lib.utils.common import cmpVersion
+from calculate.lib.datavars import DataVars
 from itertools import dropwhile
 import re
 import contextlib
@@ -35,7 +36,8 @@ from calculate.lib.cl_lang import setLocalTranslate
 
 setLocalTranslate('cl_lib3', sys.modules[__name__])
 
-_envData = [('system', '/etc/calculate/calculate.env'),
+_envData = [('system', '/var/lib/calculate/calculate.env'),
+            ('custom', '/etc/calculate/calculate.env'),
             ('local', '/var/calculate/calculate.env'),
             ('remote', '/var/calculate/remote/calculate.env')]
 
@@ -83,7 +85,7 @@ class VariableClTemplatePath(Variable):
     Path to information file on server
     """
     type = 'list'
-    value = ["/var/lib/layman/calculate/profiles/templates",
+    value = [RepositoryPath.CalculateTemplates,
              "/var/calculate/templates",
              "/var/calculate/remote/templates"]
 
@@ -763,9 +765,17 @@ class VariableClMakeProfile(Variable):
         files = ["etc/portage/make.profile", "etc/make.profile"]
         val = self.get_work_link(
             *[path.join(self.systemRoot, x) for x in files])
-        if not val:
+        if isinstance(self.parent, DataVars) and not val:
             raise VariableError(
                 _("Failed to detect the system profile.") + " " +
                 _("Select the profile with command {cmd}").format(
                     cmd="cl-update-profile"))
         return val
+
+
+class VariableClHelpSet(ReadonlyVariable):
+    """
+    Заполнение переменных выполняется для отображения --help
+    """
+    type = "bool"
+    value = "off"
